# Copyright 1999-2012 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2

EAPI="5"
inherit 1C_Enterprise

DESCRIPTION="Server component of 1C ERP system"

KEYWORDS="amd64 x86"
IUSE="postgres +fontconfig +nls pax_kernel"

RDEPEND="~app-office/1C_Enterprise-common-${PV}:${SLOT}
	postgres? (
		|| (
			dev-db/postgresql-server[1c,pg_legacytimestamp] 
			dev-db/postgresql-server:1c ) )
	fontconfig? ( gnome-extra/libgsf
		app-text/ttf2pt1
		media-gfx/imagemagick[corefonts]
		dev-db/unixODBC )"

DEPEND="${RDEPEND}"

QA_EXECSTACK="${BINDIR}/libociicus.so
	${BINDIR}/libnnz10.so
	${BINDIR}/libclntsh.so.10.1"

QA_TEXTRELS="${QA_EXECSTACK}
	${BINDIR}/image.so"

USER_1C=usr1cv${VER}

src_prepare(){
	default_src_prepare
	cp ${FILESDIR}/init srv1cv${VER}
	sed -i -e "s/#USER#/${USER_1C}/" -e "s:#BINDIR#:/${BINDIR}:" -e "s/#VER#/${VER}/" srv1cv${VER}
	sed -i -e "s:aliasFullName=\$SYSTEM_LIB_PATH/\$alias:aliasFullName=/${BINDIR}/\$alias:" \
			-e "s:checkPath lib   \$ARCH.*$:echo /usr/$(get_libdir); return:" \
			-e "s:^magickDir=...magickDir./conf/grcmncfg.$:magickDir=/${BINDIR}/conf/grcmncfg:" \
			-re '/^\s+. ".ARCH" .= "32-bit" -a ".ARCH" .= "64-bit" ] .. . echo ".MSG_UNKNOWN_ARCH"; exit 1; .$/d' \
			${BINDIR}/utils/config_server
}

pkg_setup() {
    enewgroup ${USER_1C}
    enewuser ${USER_1C} -1 -1 /var/lib/srv1c/v${VER} ${USER_1C}
}

src_install() {
	if use pax_kernel; then
		cd ${S}/${BINDIR}
		pax-mark m rphost ragent rmngr
		cd -
	fi
	1C_Enterprise_src_install
	dodoc ${S}/etc/init.d/srv1cv${VER}
	doinitd ${S}/srv1cv${VER}
	doconfd ${S}/etc/sysconfig/srv1cv${VER}
	dodir ${BINDIR}/conf/grcmncfg
}

pkg_postinst() {
	if use fontconfig ; then
		elog "You can config fonts and libs for 1C ERP system by exec"
		elog "emerge --config =${CATEGORY}/${PF}"
	fi
	if use postgresql ; then
		elog "Perhaps you should add locale en_US in /etc/localegen and"
		elog "regenerate locales to use 1C with postgres."
	fi
}
pkg_config() {
	local FONTDIR=/usr/share/fonts
	einfo "Enter FONTDIR to configure[${FONTDIR}]:"
	local answer
	read answer
	FONTDIR=${answer:=${FONTDIR}}
	/${BINDIR}/utils/config_server ${FONTDIR}
}